@@ -29,6 +29,7 @@ class ProfilesModel;
 class QMLOutput;
 class QMLScreen;
 class ControlPanel;
+class PrimaryOutputCombo;
 
 class QPushButton;
 class QComboBox;
@@ -60,9 +61,6 @@ class Widget : public QWidget
   private Q_SLOTS:
     void slotFocusedOutputChanged(QMLOutput *output);
 
-    void slotPrimaryChanged(int index);
-    void slotOutputPrimaryChanged();
-    void slotOutputConnectedChanged();
     void slotOutputEnabledChanged();
 
     void slotUnifyOutputs();
@@ -86,11 +84,11 @@ class Widget : public QWidget
     KScreen::ConfigPtr mConfig;
     KScreen::ConfigPtr mPrevConfig;
 
-    QQuickView *m_declarativeView;
-    ControlPanel *m_controlPanel;
+    QQuickView *mDeclarativeView;
+    ControlPanel *mControlPanel;
 
     ProfilesModel *mProfilesModel;
-    QComboBox *mPrimaryCombo;
+    PrimaryOutputCombo *mPrimaryCombo;
     QComboBox *mProfilesCombo;
 
     QPushButton *mUnifyButton;
